import request from '@/utils/request'

// 查询电子围栏列表
export function fenceList(data) {
  return request({
    url: '/business/fence/fenceList',
    method: 'post',
    data
  })
}

/**
 * 新增电子围栏列表
 */
export function fenceAdd(data) {
  return request({
    url: '/business/fence/fenceAdd',
    method: 'post',
    data
  })
}
/**
 * 修改电子围栏列表
 */
export function fenceUpdate(data) {
  return request({
    url: '/business/fence/fenceUpdate',
    method: 'post',
    data
  })
}

/**
 * 电子围栏删除
 * @param fenceUpdate
 * @returns {*}
 */
export function fenceDelete(data) {
  return request({
    url: '/business/fence/'+data,
    method: 'delete'
  })
}
/**
 * 电子围栏停用
 * @param data
 * @returns {*}
 */
export function changeFenceStatus(data) {
  return request({
    url: '/business/fence/fenceState',
    method: 'post',
    data
  })
}
/**
 * 查询标识
 * @param data
 * @returns {*}
 */
export function queryByLogo() {
  return request({
    url: '/business/logo/queryByLogo',
    method: 'post'
  })
}
